@@ -130,8 +130,7 @@ def dn_lookup_loop(gather_args, model, dn_parent, storage):
 
 
 def dn_lookup(gather_args, model, dn_parent, storage):
-    data = storage["input"][gather_args[KEY_GATHER]]
-
+    data = get_data(gather_args, model, dn_parent, storage)
     current_pointer = data
     for item in gather_args["dn"].split("."):
         try:
@@ -336,10 +335,13 @@ def dict_key_is_empty(item, key):
 def not_cotains(item, arg):
     return arg not in item
 
+def contains(item, arg):
+    return arg in item
 
 FILTERS = {
     "dict_key_is_empty": dict_key_is_empty,
     "not_contains": not_cotains,
+    "contains": contains,
     "default": always_false,
 }
 
@@ -377,12 +379,17 @@ def create_uuid5(domain, id):
     return str(uuid.uuid5(namespace, id))
 
 
+def format_dict_to_key_list(item, **kwargs):
+    return [key for key in item.keys()]
+
+
 POSTFORMAT = {
     "default": default_postformat,
     "int_to_iso_timestamp": int_to_iso_timestamp,
     "regex_to_iso_timestamp": regex_to_iso_timestamp,
     "regex_search": regex_search,
     "hash_uuid": create_uuid5,
+    "format_dict_to_key_list": format_dict_to_key_list,
 }
 
 
@@ -523,6 +530,7 @@ def list_item(model, dn, value):
         "description": model.get("description"),
         "type": model["type"],
         "field_type": model.get("field_type"),
+        "searchable": model.get("searchable", True),
     }
     item.update(STORAGE[KEY_STORAGE_LIST_ITEM])
     return item
